@@ -188,3 +188,29 @@ int BackupFromPython(PyObject *dict, GSM_Backup *backup) {
 
     return 1;
 }
+
+int BackupFormatFromString(const char *s, GSM_BackupFormat *format) {
+    if (strcmp(s, "LMB") == 0) {
+        *format = GSM_Backup_LMB;
+    } else if (strcmp(s, "VCalendar") == 0) {
+        *format = GSM_Backup_VCalendar;
+    } else if (strcmp(s,"VCard") == 0) {
+        *format = GSM_Backup_VCard;
+    } else if (strcmp(s,"LDIF") == 0) {
+        *format = GSM_Backup_LDIF;
+    } else if (strcmp(s,"ICS") == 0) {
+        *format = GSM_Backup_ICS;
+    } else if (strcmp(s,"Gammu") == 0) {
+        *format = GSM_Backup_Gammu;
+    } else if (strcmp(s,"GammuUCS2") == 0) {
+        *format = GSM_Backup_GammuUCS2;
+    } else if (strcmp(s,"Auto") == 0) {
+        *format = GSM_Backup_Auto;
+    } else if (strcmp(s,"AutoUnicode") == 0) {
+        *format = GSM_Backup_AutoUnicode;
+    } else {
+        PyErr_Format(PyExc_ValueError, "Bad value for format: '%s'", s);
+        return 0;
+    }
+    return 1;
+}
