@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,10 +14,13 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
 /* Basic getters from Python objects */
 
+#include "pyg-config.h"
 #include "convertors.h"
 #include "misc.h"
 
@@ -186,7 +189,7 @@ char *GetCharFromDict(PyObject *dict, char *key) {
     return ps;
 }
 
-char *GetDataFromDict(PyObject *dict, char *key, int *len) {
+char *GetDataFromDict(PyObject *dict, char *key, Py_ssize_t *len) {
     PyObject        *o;
     char            *ps;
 
