@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,10 +14,13 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
 /* Calendar related conversions */
 
+#include "pyg-config.h"
 #include "convertors.h"
 #include "misc.h"
 
@@ -112,12 +115,14 @@ PyObject *CalendarToPython(const GSM_CalendarEntry *entry) {
     Py_UNICODE      *s;
     char            *t;
     GSM_DateTime    dt;
+    int             ignore;
 
     v = PyList_New(0);
     if (v == NULL) return NULL;
 
     for (i=0; i < entry->EntriesNum; i++) {
         f = Py_None;
+        ignore = 0;
         switch (entry->Entries[i].EntryType) {
             case CAL_START_DATETIME:
                 /* Fixup date */
@@ -142,6 +147,11 @@ PyObject *CalendarToPython(const GSM_CalendarEntry *entry) {
             case CAL_END_DATETIME:
                 /* Fixup date */
                 dt = entry->Entries[i].Date;
+                if (dt.Year == 0) {
+                    /* Ignore, there can be none end date. */
+                    ignore = 1;
+                    break;
+                }
                 if (dt.Hour == 255) {
                     dt.Hour = 23;
                 }
@@ -177,6 +187,15 @@ PyObject *CalendarToPython(const GSM_CalendarEntry *entry) {
                 f = Py_BuildValue("{s:s,s:O,s:i}", "Type", "SILENT_ALARM_DATETIME", "Value", d, "AddError", (int)entry->Entries[i].AddError);
                 Py_DECREF(d);
                 break;
+            case CAL_LAST_MODIFIED:
+                d = BuildPythonDateTime(&(entry->Entries[i].Date));
+                if (d == NULL) {
+                    Py_DECREF(v);
+                    return NULL;
+                }
+                f = Py_BuildValue("{s:s,s:O,s:i}", "Type", "LAST_MODIFIED", "Value", d, "AddError", (int)entry->Entries[i].AddError);
+                Py_DECREF(d);
+                break;
             case CAL_REPEAT_STARTDATE:
                 d = BuildPythonDateTime(&(entry->Entries[i].Date));
                 if (d == NULL) {
@@ -263,6 +282,16 @@ PyObject *CalendarToPython(const GSM_CalendarEntry *entry) {
             case CAL_REPEAT_FREQUENCY:
                 f = Py_BuildValue("{s:s,s:i,s:i}", "Type", "REPEAT_FREQUENCY", "Value", entry->Entries[i].Number, "AddError", (int)entry->Entries[i].AddError);
                 break;
+            case CAL_REPEAT_COUNT:
+                f = Py_BuildValue("{s:s,s:i,s:i}", "Type", "REPEAT_COUNT", "Value", entry->Entries[i].Number, "AddError", (int)entry->Entries[i].AddError);
+                break;
+            case CAL_REPEAT_DAYOFYEAR:
+                f = Py_BuildValue("{s:s,s:i,s:i}", "Type", "REPEAT_DAYOFYEAR", "Value", entry->Entries[i].Number, "AddError", (int)entry->Entries[i].AddError);
+                break;
+        }
+
+        if (ignore) {
+            continue;
         }
 
         if (f == Py_None) {
@@ -366,6 +395,9 @@ int CalendarFromPython(PyObject *dict, GSM_CalendarEntry *entry, int needs_locat
         } else if (strcmp("SILENT_ALARM_DATETIME", type) == 0) {
             valuetype = 'd';
             entry->Entries[i].EntryType = CAL_SILENT_ALARM_DATETIME;
+        } else if (strcmp("LAST_MODIFIED", type) == 0) {
+            valuetype = 'd';
+            entry->Entries[i].EntryType = CAL_LAST_MODIFIED;
         } else if (strcmp("REPEAT_STARTDATE", type) == 0) {
             valuetype = 'D';
             entry->Entries[i].EntryType = CAL_REPEAT_STARTDATE;
@@ -410,6 +442,12 @@ int CalendarFromPython(PyObject *dict, GSM_CalendarEntry *entry, int needs_locat
         } else if (strcmp("REPEAT_FREQUENCY", type) == 0) {
             valuetype = 'n';
             entry->Entries[i].EntryType = CAL_REPEAT_FREQUENCY;
+        } else if (strcmp("REPEAT_COUNT", type) == 0) {
+            valuetype = 'n';
+            entry->Entries[i].EntryType = CAL_REPEAT_COUNT;
+        } else if (strcmp("REPEAT_DAYOFYEAR", type) == 0) {
+            valuetype = 'n';
+            entry->Entries[i].EntryType = CAL_REPEAT_DAYOFYEAR;
 
         } else {
             PyErr_Format(PyExc_ValueError, "Element %i in Values has bad type: %s", i, type);
