@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,11 +14,14 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
 /* MemoryEntry conversions */
 #undef USE_PREF_UNICODE
 
+#include "pyg-config.h"
 #include "convertors.h"
 #include "misc.h"
 
@@ -89,6 +92,9 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_Text_Postal:
                 convert_text("Text_Postal");
                 break;
+            case PBK_Text_WorkPostal:
+                convert_text("Text_WorkPostal");
+                break;
             case PBK_Text_Email:
                 convert_text("Text_Email");
                 break;
@@ -107,6 +113,15 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
                 f = Py_BuildValue("{s:s,s:O}", "Type", "Date", "Value", d);
                 Py_DECREF(d);
                 break;
+            case PBK_LastModified:
+                d = BuildPythonDateTime(&(entry->Entries[i].Date));
+                if (d == NULL) {
+                    Py_DECREF(v);
+                    return NULL;
+                }
+                f = Py_BuildValue("{s:s,s:O}", "Type", "LastModified", "Value", d);
+                Py_DECREF(d);
+                break;
             case PBK_Caller_Group:
                 f = Py_BuildValue("{s:s,s:i}", "Type", "Caller_Group", "Value", entry->Entries[i].Number);
                 break;
@@ -119,6 +134,12 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_Text_FirstName:
                 convert_text("Text_FirstName");
                 break;
+            case PBK_Text_NickName:
+                convert_text("Text_NickName");
+                break;
+            case PBK_Text_FormalName:
+                convert_text("Text_FormalName");
+                break;
             case PBK_Text_Company:
                 convert_text("Text_Company");
                 break;
@@ -146,6 +167,21 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_Text_Country:
                 convert_text("Text_Country");
                 break;
+            case PBK_Text_WorkStreetAddress:
+                convert_text("Text_WorkStreetAddress");
+                break;
+            case PBK_Text_WorkCity:
+                convert_text("Text_WorkCity");
+                break;
+            case PBK_Text_WorkState:
+                convert_text("Text_WorkState");
+                break;
+            case PBK_Text_WorkZip:
+                convert_text("Text_WorkZip");
+                break;
+            case PBK_Text_WorkCountry:
+                convert_text("Text_WorkCountry");
+                break;
             case PBK_Text_Custom1:
                 convert_text("Text_Custom1");
                 break;
@@ -164,21 +200,21 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_Text_UserID:
                 convert_text("Text_UserID");
                 break;
+            case PBK_Text_PictureName:
+                convert_text("Text_PictureName");
+                break;
             case PBK_RingtoneID:
                 f = Py_BuildValue("{s:s,s:O}", "Type", "RingtoneID", "Value", PyLong_FromUnsignedLong(entry->Entries[i].Number));
                 break;
             case PBK_PictureID:
                 f = Py_BuildValue("{s:s,s:O}", "Type", "PictureID", "Value", PyLong_FromUnsignedLong(entry->Entries[i].Number));
                 break;
-            case PBK_RingtoneFileSystemID:
-                f = Py_BuildValue("{s:s,s:O}", "Type", "RingtoneID", "Value", PyLong_FromUnsignedLong(entry->Entries[i].Number));
-                break;
-            case PBK_SMSListID:
-                f = Py_BuildValue("{s:s,s:O}", "Type", "SMSListID", "Value", PyLong_FromUnsignedLong(entry->Entries[i].Number));
-                break;
             case PBK_CallLength:
                 f = Py_BuildValue("{s:s,s:i}", "Type", "CallLength", "Value", entry->Entries[i].CallLength);
                 break;
+            case PBK_PushToTalkID:
+                convert_text("PushToTalkID");
+                break;
         }
 
         if (f == Py_None) {
@@ -316,6 +352,9 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("Text_Postal", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_Postal;
+        } else if (strcmp("Text_WorkPostal", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_WorkPostal;
         } else if (strcmp("Text_Email", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_Email;
@@ -328,6 +367,9 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("Date", type) == 0) {
             valuetype = 'd';
             entry->Entries[i].EntryType = PBK_Date;
+        } else if (strcmp("LastModified", type) == 0) {
+            valuetype = 'd';
+            entry->Entries[i].EntryType = PBK_LastModified;
         } else if (strcmp("Caller_Group", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Caller_Group;
@@ -340,6 +382,12 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("Text_FirstName", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_FirstName;
+        } else if (strcmp("Text_NickName", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_NickName;
+        } else if (strcmp("Text_FormalName", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_FormalName;
         } else if (strcmp("Text_Company", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_Company;
@@ -367,6 +415,21 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("Text_Country", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_Country;
+        } else if (strcmp("Text_WorkStreetAddress", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_WorkStreetAddress;
+        } else if (strcmp("Text_WorkCity", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_WorkCity;
+        } else if (strcmp("Text_WorkState", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_WorkState;
+        } else if (strcmp("Text_WorkZip", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_WorkZip;
+        } else if (strcmp("Text_WorkCountry", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_WorkCountry;
         } else if (strcmp("Text_Custom1", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_Custom1;
@@ -385,21 +448,21 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("Text_UserID", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_UserID;
+        } else if (strcmp("Text_PictureName", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_PictureName;
         } else if (strcmp("RingtoneID", type) == 0) {
             valuetype = 'n';
             entry->Entries[i].EntryType = PBK_RingtoneID;
-        } else if (strcmp("RingtoneFileSystemID", type) == 0) {
-            valuetype = 'n';
-            entry->Entries[i].EntryType = PBK_RingtoneFileSystemID;
         } else if (strcmp("PictureID", type) == 0) {
             valuetype = 'n';
             entry->Entries[i].EntryType = PBK_PictureID;
-        } else if (strcmp("SMSListID", type) == 0) {
-            valuetype = 'n';
-            entry->Entries[i].EntryType = PBK_SMSListID;
         } else if (strcmp("CallLength", type) == 0) {
             valuetype = 'c';
             entry->Entries[i].EntryType = PBK_CallLength;
+        } else if (strcmp("PushToTalkID", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_PushToTalkID;
         } else {
             PyErr_Format(PyExc_ValueError, "Element %i in Entries has bad type: %s", i, type);
             return 0;
