@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,9 +14,13 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
 /* Miscellaneous conversions, that didn't fit elsewhere */
+
+#include "pyg-config.h"
 #include "convertors.h"
 
 
@@ -88,3 +92,81 @@ PyObject *CBToPython(GSM_CBMessage *cb) {
             "Text", cb->Text
             );
 }
+
+GSM_USSDStatus StringToUSSDStatus(const char *s) {
+	if (strcmp(s, "Unknown") == 0) return USSD_Unknown;
+	else if (strcmp(s, "NoActionNeeded") == 0) return USSD_NoActionNeeded;
+	else if (strcmp(s, "ActionNeeded") == 0) return USSD_ActionNeeded;
+	else if (strcmp(s, "Terminated") == 0) return USSD_Terminated;
+	else if (strcmp(s, "AnotherClient") == 0) return USSD_AnotherClient;
+	else if (strcmp(s, "NotSupported") == 0) return USSD_NotSupported;
+	else if (strcmp(s, "Timeout") == 0) return USSD_Timeout;
+
+    PyErr_Format(PyExc_ValueError, "Bad value for USSD Status '%s'", s);
+    return 0;
+}
+
+char *USSDStatusToString(GSM_USSDStatus type) {
+    char *err = "Err";
+    char *s = err;
+
+    switch (type) {
+		case USSD_Unknown:
+			s = strdup("Unknown");
+			break;
+		case USSD_NoActionNeeded:
+			s = strdup("NoActionNeeded");
+			break;
+		case USSD_ActionNeeded:
+			s = strdup("ActionNeeded");
+			break;
+		case USSD_Terminated:
+			s = strdup("Terminated");
+			break;
+		case USSD_AnotherClient:
+			s = strdup("AnotherClient");
+			break;
+		case USSD_NotSupported:
+			s = strdup("NotSupported");
+			break;
+		case USSD_Timeout:
+			s = strdup("Timeout");
+			break;
+    }
+
+    if (s == err) {
+        PyErr_Format(PyExc_ValueError, "Bad value for USSD Status from Gammu: '%d'", type);
+        return NULL;
+    }
+
+    if (s == NULL) {
+        PyErr_SetString(PyExc_MemoryError, "Not enough memory to allocate string");
+        return NULL;
+    }
+
+    return s;
+}
+
+PyObject *USSDToPython(GSM_USSDMessage *ussd) {
+    PyObject *text;
+    PyObject *result;
+    char        *status;
+
+    status = USSDStatusToString(ussd->Status);
+    if (status == NULL) return NULL;
+
+    text = UnicodeStringToPython(ussd->Text);
+    if (text == NULL) {
+        free(status);
+        return NULL;
+    }
+
+    result = Py_BuildValue("{s:s,s:O}",
+            "Status", status,
+            "Text", text
+            );
+
+    Py_DECREF(text);
+    free(status);
+    return result;
+}
