@@ -1919,13 +1919,3 @@ int SMSBackupFromPython(PyObject *list, GSM_SMS_Backup *sms) {
 
     return 1;
 }
-
-void FreeSMSBackup(GSM_SMS_Backup *sms) {
-    int         i = 0;
-
-    while (sms->SMS[i] != NULL) {
-        free(sms->SMS[i]);
-        sms->SMS[i] = NULL;
-        i++;
-    }
-}
