@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,9 +14,13 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
 /* Unicode strings conversion between Gammu and Python */
+
+#include "pyg-config.h"
 #include "convertors.h"
 
 unsigned char *StringPythonToGammu(PyObject *o) {
@@ -110,7 +114,7 @@ PyObject *UnicodeStringToPythonL(const unsigned char *src, const int len) {
     return res;
 }
 
-PyObject *LocaleStringToPython(char *src) {
+PyObject *LocaleStringToPython(const char *src) {
     unsigned char   *w;
     size_t          len;
     PyObject        *ret;
