@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,10 +14,13 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
 /* ToDo related conversions */
 
+#include "pyg-config.h"
 #include "convertors.h"
 #include "misc.h"
 
@@ -98,6 +101,15 @@ PyObject *TodoToPython(const GSM_ToDoEntry *entry) {
                 f = Py_BuildValue("{s:s,s:O}", "Type", "SILENT_ALARM_DATETIME", "Value", d);
                 Py_DECREF(d);
                 break;
+            case TODO_LAST_MODIFIED:
+                d = BuildPythonDateTime(&(entry->Entries[i].Date));
+                if (d == NULL) {
+                    Py_DECREF(v);
+                    return NULL;
+                }
+                f = Py_BuildValue("{s:s,s:O}", "Type", "LAST_MODIFIED", "Value", d);
+                Py_DECREF(d);
+                break;
             case TODO_TEXT:
                 s = strGammuToPython(entry->Entries[i].Text);
                 if (s == NULL) {
@@ -273,6 +285,9 @@ int TodoFromPython(PyObject *dict, GSM_ToDoEntry *entry, int needs_location) {
         } else if (strcmp("SILENT_ALARM_DATETIME", type) == 0) {
             valuetype = 'd';
             entry->Entries[i].EntryType = TODO_SILENT_ALARM_DATETIME;
+        } else if (strcmp("LAST_MODIFIED", type) == 0) {
+            valuetype = 'd';
+            entry->Entries[i].EntryType = TODO_LAST_MODIFIED;
         } else if (strcmp("LUID", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = TODO_LUID;
