@@ -76,6 +76,13 @@ PyObject *PyERR_FOLDERPART;
 PyObject *PyERR_FOLDERNOTEMPTY;
 PyObject *PyERR_DATACONVERTED;
 PyObject *PyERR_UNCONFIGURED;
+PyObject *PyERR_WRONGFOLDER;
+PyObject *PyERR_PHONE_INTERNAL;
+PyObject *PyERR_WRITING_FILE;
+PyObject *PyERR_NONE_SECTION;
+PyObject *PyERR_USING_DEFAULTS;
+PyObject *PyERR_CORRUPTED;
+PyObject *PyERR_LAST_VALUE;
 
 int checkError(GSM_StateMachine *s, GSM_Error error, char *where) {
     PyObject    *val;
@@ -138,6 +145,13 @@ int checkError(GSM_StateMachine *s, GSM_Error error, char *where) {
         case ERR_FOLDERNOTEMPTY: err = PyERR_FOLDERNOTEMPTY; break;
         case ERR_DATACONVERTED: err = PyERR_DATACONVERTED; break;
         case ERR_UNCONFIGURED: err = PyERR_UNCONFIGURED; break;
+        case ERR_WRONGFOLDER: err = PyERR_WRONGFOLDER; break;
+        case ERR_PHONE_INTERNAL: err = PyERR_PHONE_INTERNAL; break;
+        case ERR_WRITING_FILE: err = PyERR_WRITING_FILE; break;
+        case ERR_NONE_SECTION: err = PyERR_NONE_SECTION; break;
+        case ERR_USING_DEFAULTS: err = PyERR_USING_DEFAULTS; break;
+        case ERR_CORRUPTED: err = PyERR_CORRUPTED; break;
+        case ERR_LAST_VALUE: err = PyERR_LAST_VALUE; break;
     }
 
     msg = GSM_ErrorString(error);
@@ -276,6 +290,13 @@ int gammu_create_errors(PyObject *d) {
     CREATE_ERROR(ERR_FOLDERNOTEMPTY)
     CREATE_ERROR(ERR_DATACONVERTED)
     CREATE_ERROR(ERR_UNCONFIGURED)
+    CREATE_ERROR(ERR_WRONGFOLDER)
+    CREATE_ERROR(ERR_PHONE_INTERNAL)
+    CREATE_ERROR(ERR_WRITING_FILE)
+    CREATE_ERROR(ERR_NONE_SECTION)
+    CREATE_ERROR(ERR_USING_DEFAULTS)
+    CREATE_ERROR(ERR_CORRUPTED)
+    CREATE_ERROR(ERR_LAST_VALUE)
 
     PyDict_SetItemString(d, "Errors", error_list);
     Py_DECREF(error_list);
